@@ -253,14 +253,14 @@ check.max.degree <- function(xdat=NULL,degree=NULL,issue.warning=FALSE,Bernstein
         ## If the max degree is ill-conditioned then ascend
         ## (descending may require computation of large matrices that
         ## are discarded)
-        if(rcond(t(X)%*%X)<.Machine$double.eps) {
+        if(!is.fullrank(X)) {
           for(j in 1:degree[i]) {
             d[i] <- j
             X <- mypoly(x=xdat[,numeric.index[i]],
                         ex=NULL,
                         degree=d[i],
                         Bernstein=Bernstein)
-            if(rcond(t(X)%*%X)<.Machine$double.eps) {
+            if(!is.fullrank(X)) {
               d[i] <- j-1
               break()
             }
@@ -563,6 +563,7 @@ npglpreg.formula <- function(formula,
                              bandwidth.min=1.0e-02,
                              gradient.vec=NULL,
                              gradient.categorical=FALSE,
+                             ridge=TRUE,
                              ridge.warning=FALSE,
                              Bernstein=TRUE,
                              ...) {
@@ -605,6 +606,7 @@ npglpreg.formula <- function(formula,
                                                    degree.min=degree.min,
                                                    bandwidth.max=bandwidth.max,
                                                    bandwidth.min=bandwidth.min,
+                                                   ridge=ridge,                                                   
                                                    ridge.warning=ridge.warning,
                                                    Bernstein=Bernstein,
                                                    ...))
@@ -633,7 +635,8 @@ npglpreg.formula <- function(formula,
                                                    bwtype=bwtype,
                                                    gradient.vec=gradient.vec,
                                                    gradient.categorical=gradient.categorical,
-                                                   ridge.warning=ridge.warning,
+                                                   ridge=ridge,
+                                                   ridge.warning=ridge.warning,                                                   
                                                    Bernstein=Bernstein,
                                                    ...))
   
@@ -663,6 +666,7 @@ glpregEst <- function(tydat=NULL,
                       okertype=c("liracine","wangvanryzin"),
                       bwtype=c("fixed","generalized_nn","adaptive_nn"),
                       gradient.vec=NULL,
+                      ridge=TRUE,
                       ridge.warning=FALSE,
                       Bernstein=TRUE,
                       ...) {
@@ -791,7 +795,7 @@ glpregEst <- function(tydat=NULL,
     ## Test for ill-conditioned polynomial basis and return a large
     ## penalty when this occurs
 
-    if(rcond(t(W)%*%W)<.Machine$double.eps)
+    if(!is.fullrank(W))
       stop(" Ill-conditioned polynomial basis encountered: modify polynomial order")
 
     if(miss.ex) {
@@ -856,6 +860,20 @@ glpregEst <- function(tydat=NULL,
     tyw <- array(tww,dim = c(ncol(W)+1,ncol(W),n.eval))[1,,]
     tww <- array(tww,dim = c(ncol(W)+1,ncol(W),n.eval))[-1,,]
 
+    if(!ridge) {
+      ## We can choose to use ridging or simply check for less than
+      ## full column rank. If we test for full column rank ridging
+      ## ought never occur but this is quite strong as if one
+      ## observation only is sparse and inversion is problematic, for
+      ## the rest of the sample this may not be the case.
+      for(i in 1:n.eval) {
+        if(!is.fullrank(tww[,,i])) {
+          if(ridge.warning) console <- printPush(paste("\rWarning: is.fullrank required for inversion at obs. ", i," failed",sep=""),console = console)
+          return(sqrt(.Machine$double.xmax))
+        }
+      }
+    }
+      
     ## This traps the case with one evaluation point where we need to
     ## keep the extra dimension.
 
@@ -933,6 +951,7 @@ minimand.cv.ls <- function(bws=NULL,
                            ukertype=c("liracine","aitchisonaitken"),
                            okertype=c("liracine","wangvanryzin"),
                            bwtype = c("fixed","generalized_nn","adaptive_nn"),
+                           ridge=TRUE,
                            ridge.warning=FALSE,
                            ...) {
 
@@ -1012,6 +1031,20 @@ minimand.cv.ls <- function(bws=NULL,
       tyw <- array(tww,dim = c(ncol(W)+1,ncol(W),n))[1,,]
       tww <- array(tww,dim = c(ncol(W)+1,ncol(W),n))[-1,,]
 
+      if(!ridge) {
+        ## We can choose to use ridging or simply check for less than
+        ## full column rank. If we test for full column rank ridging
+        ## ought never occur but this is quite strong as if one
+        ## observation only is sparse and inversion is problematic, for
+        ## the rest of the sample this may not be the case.
+        for(i in 1:n) {
+          if(!is.fullrank(tww[,,i])) {
+            if(ridge.warning) console <- printPush(paste("\rWarning: is.fullrank required for inversion at obs. ", i," failed",sep=""),console = console)
+            return(sqrt(.Machine$double.xmax))
+          }
+        }
+      }
+      
       mean.loo <- rep(maxPenalty,n)
       epsilon <- 1.0/n
       ridge <- double(n)
@@ -1067,6 +1100,7 @@ minimand.cv.aic <- function(bws=NULL,
                             ukertype=c("liracine","aitchisonaitken"),
                             okertype=c("liracine","wangvanryzin"),
                             bwtype = c("fixed","generalized_nn","adaptive_nn"),
+                            ridge=TRUE,
                             ridge.warning=FALSE,
                             ...) {
 
@@ -1154,6 +1188,20 @@ minimand.cv.aic <- function(bws=NULL,
       tyw <- array(tww,dim = c(ncol(W)+1,ncol(W),n))[1,,]
       tww <- array(tww,dim = c(ncol(W)+1,ncol(W),n))[-1,,]
 
+      if(!ridge) {
+        ## We can choose to use ridging or simply check for less than
+        ## full column rank. If we test for full column rank ridging
+        ## ought never occur but this is quite strong as if one
+        ## observation only is sparse and inversion is problematic, for
+        ## the rest of the sample this may not be the case.
+        for(i in 1:n) {
+          if(!is.fullrank(tww[,,i])) {
+            if(ridge.warning) console <- printPush(paste("\rWarning: is.fullrank required for inversion at obs. ", i," failed",sep=""),console = console)
+            return(sqrt(.Machine$double.xmax))
+          }
+        }
+      }
+
       ghat <- rep(maxPenalty,n)
       epsilon <- 1.0/n
       ridge <- double(n)
@@ -1276,7 +1324,7 @@ glpcv <- function(ydat=NULL,
              degree=degree,
              Bernstein=Bernstein)
 
-  if(rcond(t(W)%*%W)<.Machine$double.eps)
+  if(!is.fullrank(W))
     return(sqrt(.Machine$double.xmax))
 
   sum.lscv <- function(bw.gamma,...) {
@@ -1291,7 +1339,7 @@ glpcv <- function(ydat=NULL,
                              xdat=xdat,
                              ukertype=ukertype,
                              okertype=okertype,
-                             bwtype=bwtype,                    
+                             bwtype=bwtype,
                              ...)
     } else {
       lscv <- maxPenalty
@@ -1470,6 +1518,7 @@ glpcvNOMAD <- function(ydat=NULL,
                          "INITIAL_MESH_SIZE"=paste("r",1.0e-04,sep=""),
                          "MIN_MESH_SIZE"=paste("r",1.0e-05,sep=""),
                          "MIN_POLL_SIZE"=paste("r",1.0e-05,sep="")),
+                       ridge=TRUE,
                        ridge.warning=FALSE,
                        Bernstein=TRUE,
                        ...) {
@@ -1625,7 +1674,8 @@ glpcvNOMAD <- function(ydat=NULL,
     ukertype <- params$ukertype
     okertype <- params$okertype
     bwtype <- params$bwtype
-    ridge.warning <- params$ridge.warning
+    ridge <- params$ridge
+    ridge.warning <- params$ridge.warning    
     Bernstein <- params$Bernstein
 
     bw.gamma <- input[1:num.bw]
@@ -1636,7 +1686,7 @@ glpcvNOMAD <- function(ydat=NULL,
                degree=degree,
                Bernstein=Bernstein)
 
-    if(rcond(t(W)%*%W)<.Machine$double.eps)
+    if(!is.fullrank(W))
       return(sqrt(.Machine$double.xmax))
 
     if(all(bw.gamma>=0)&&all(bw.gamma[!xdat.numeric]<=1)) {
@@ -1648,6 +1698,7 @@ glpcvNOMAD <- function(ydat=NULL,
                              ukertype=ukertype,
                              okertype=okertype,
                              bwtype=bwtype,
+                             ridge=ridge,
                              ridge.warning=ridge.warning,
                              ...)
     } else {
@@ -1670,7 +1721,8 @@ glpcvNOMAD <- function(ydat=NULL,
     ukertype <- params$ukertype
     okertype <- params$okertype
     bwtype <- params$bwtype
-    ridge.warning <- params$ridge.warning
+    ridge <- params$ridge
+    ridge.warning <- params$ridge.warning    
     Bernstein <- params$Bernstein
     
     bw.gamma <- input[1:num.bw]
@@ -1681,7 +1733,7 @@ glpcvNOMAD <- function(ydat=NULL,
                degree=degree,
                Bernstein=Bernstein)
 
-    if(rcond(t(W)%*%W)<.Machine$double.eps)
+    if(!is.fullrank(W))
       return(sqrt(.Machine$double.xmax))
 
     if(all(bw.gamma>=0)&&all(bw.gamma[!xdat.numeric]<=1)) {
@@ -1693,6 +1745,7 @@ glpcvNOMAD <- function(ydat=NULL,
                               ukertype=ukertype,
                               okertype=okertype,
                               bwtype=bwtype,
+                              ridge=ridge,
                               ridge.warning=ridge.warning,
                               ...)
     } else {
@@ -1716,6 +1769,7 @@ glpcvNOMAD <- function(ydat=NULL,
   params$ukertype <- ukertype
   params$okertype <- okertype
   params$bwtype <- bwtype
+  params$ridge <- ridge  
   params$ridge.warning <- ridge.warning
   params$Bernstein <- Bernstein
 
